Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(139)

Unified Diff: sync/internal_api/public/engine/model_safe_worker.h

Issue 10696087: [Sync] Move ModelType and related classes to 'syncer' namespace (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: sort headers, update copyrights Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « sync/internal_api/public/base_transaction.h ('k') | sync/internal_api/public/engine/model_safe_worker.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: sync/internal_api/public/engine/model_safe_worker.h
diff --git a/sync/internal_api/public/engine/model_safe_worker.h b/sync/internal_api/public/engine/model_safe_worker.h
index ce14c1db0c52259c0e2de01f72fbfded3adfb1e3..5c9c7aef54f7d60de51a260f16034cb4f011f460 100644
--- a/sync/internal_api/public/engine/model_safe_worker.h
+++ b/sync/internal_api/public/engine/model_safe_worker.h
@@ -64,10 +64,10 @@ class ModelSafeWorker : public base::RefCountedThreadSafe<ModelSafeWorker> {
friend class base::RefCountedThreadSafe<ModelSafeWorker>;
};
// A map that details which ModelSafeGroup each syncable::ModelType
// belongs to. Routing info can change in response to the user enabling /
// disabling sync for certain types, as well as model association completions.
-typedef std::map<syncable::ModelType, ModelSafeGroup>
+typedef std::map<syncer::ModelType, ModelSafeGroup>
ModelSafeRoutingInfo;
// Caller takes ownership of return value.
@@ -79,14 +79,14 @@ std::string ModelSafeRoutingInfoToString(
// Make a ModelTypePayloadMap for all the enabled types in a
// ModelSafeRoutingInfo using a default payload.
-syncable::ModelTypePayloadMap ModelSafeRoutingInfoToPayloadMap(
+syncer::ModelTypePayloadMap ModelSafeRoutingInfoToPayloadMap(
const ModelSafeRoutingInfo& routes,
const std::string& payload);
-syncable::ModelTypeSet GetRoutingInfoTypes(
+syncer::ModelTypeSet GetRoutingInfoTypes(
const ModelSafeRoutingInfo& routing_info);
-ModelSafeGroup GetGroupForModelType(const syncable::ModelType type,
+ModelSafeGroup GetGroupForModelType(const syncer::ModelType type,
const ModelSafeRoutingInfo& routes);
} // namespace syncer
« no previous file with comments | « sync/internal_api/public/base_transaction.h ('k') | sync/internal_api/public/engine/model_safe_worker.cc » ('j') | no next file with comments »
@@ -64,10 +64,10 @@ class ModelSafeWorker : public base::RefCountedThreadSafe<ModelSafeWorker> {
friend class base::RefCountedThreadSafe<ModelSafeWorker>;
};
-// A map that details which ModelSafeGroup each syncable::ModelType
+// A map that details which ModelSafeGroup each syncer::ModelType
// belongs to. Routing info can change in response to the user enabling /
// disabling sync for certain types, as well as model association completions.

Powered by Google App Engine
This is Rietveld 408576698